use clap::Parser;
use sha1::{Digest, Sha1};
use std::fs::File;
use std::io::{self, Read};

#[derive(Parser)]
#[command(name = "VeriSHA1")]
#[command(author = "Hokori")]
#[command(version = "1.0")]
#[command(about = "验证文件的SHA1值", long_about = None)]
#[command(disable_help_flag = true)]
struct Cli {
    #[arg(short = 'p', long)]
    path: String,

    #[arg(short = 'h', long)]
    hash: Option<String>,

    #[arg(long, action = clap::ArgAction::Help, help = "Print help")]
    help: Option<bool>,
}

fn main() -> io::Result<()> {
    let cli = Cli::parse();

    let mut file = File::open(cli.path)?;
    let mut hasher = Sha1::new();
    let mut buffer = Vec::new();

    file.read_to_end(&mut buffer)?;
    hasher.update(&buffer);

    let result = hasher.finalize();
    let hex_result = hex::encode(result);

    match cli.hash {
        Some(hash_value) => {
            if hex_result.to_lowercase() == hash_value.to_lowercase() {
                println!("SHA1值匹配");
            } else {
                println!("SHA1值不匹配");
                println!("文件的SHA1值为: {}", hex_result);
            }
        }
        None => {
            println!("文件的SHA1值为: {}", hex_result);
        }
    }

    Ok(())
}
